<template>
  <div class="locale-dropdown">
    <Dropdown trigger="click" @on-click="selectLang">
      <a href="javascript:;">
        {{ title }}
        <Icon :size="18" color="#fff" type="md-arrow-dropdown"></Icon>
      </a>
      <template #list>
        <DropdownMenu>
          <DropdownItem
            v-for="(value, key) in localeList"
            :selected="key == locale"
            :name="key"
            :key="key"
            >{{ value }}</DropdownItem
          >
        </DropdownMenu>
      </template>
    </Dropdown>
  </div>
</template>

<script>
import { useI18n } from "vue-i18n";
import { localSave, localRead } from "@/libs/util";
const localeKey = "locale";
export default {
  name: "LayoutLocale",
  data() {
    return {
      lang: "",
      langList: {
        "zh-CN": "语言",
        "en-US": "Lang",
      },
      localeList: {
        "zh-CN": "中文简体",
        "en-US": "English",
      },
    };
  },
  computed: {
    title() {
      return this.langList[this.lang];
    },
  },
  methods: {
    selectLang(name) {
      this.setLocal(name);
      this.changeLang(name);
    },
    setLocal(name) {
      this.lang = name;
      localSave(localeKey, name);
    },
  },
  mounted() {
    this.lang = localRead(localeKey) || "zh-CN";
    this.selectLang(this.lang);
  },
  setup() {
    const { locale } = useI18n();
    const changeLang = (name) => {
      locale.value = name;
    };
    return { locale, changeLang };
  },
};
</script>

<style lang="less" scoped>
.locale-dropdown {
  margin-right: 10px;
  float: right;
  a {
    color: #fff;
  }
}
</style>